@@ -15,7 +15,7 @@ from typing import (
 import astor
 from pydoctor import epydoc2stan, model, node2stan
 from pydoctor.epydoc.markup._pyval_repr import colorize_inline_pyval
-from pydoctor.astutils import bind_args, node2dottedname
+from pydoctor.astutils import bind_args, node2dottedname, is__name__equals__main__
 
 def parseFile(path: Path) -> ast.Module:
     """Parse the contents of a Python source file."""
@@ -220,6 +220,15 @@ class ModuleVistor(ast.NodeVisitor):
                 self.currAttr = self.newAttr
             self.newAttr = None
 
+    def visit_If(self, node: ast.If) -> None:
+        if isinstance(node.test, ast.Compare):
+            if is__name__equals__main__(node.test):
+                # skip if __name__ == '__main__': blocks since
+                # whatever is declared in them cannot be imported
+                # and thus is not part of the API
+                return
+        self.default(node)
+
     def visit_Module(self, node: ast.Module) -> None:
         assert self.module.docstring is None
 
@@ -388,10 +397,9 @@ class ModuleVistor(ast.NodeVisitor):
 
             # Move re-exported objects into current module.
             if asname in exports and mod is not None:
-                try:
-                    ob = mod.contents[orgname]
-                except KeyError:
-                    self.builder.warning("cannot find re-exported name",
+                ob = mod.resolveName(orgname)
+                if ob is None:
+                    self.builder.warning("cannot resolve re-exported name",
                                          f'{modname}.{orgname}')
                 else:
                     if mod.all is None or orgname not in mod.all:
@@ -516,7 +524,7 @@ class ModuleVistor(ast.NodeVisitor):
             # and therefore doesn't need an Attribute instance.
             return
         parent = self.builder.current
-        obj = parent.resolveName(target)
+        obj = parent.contents.get(target)
         
         if obj is None:
             obj = self.builder.addAttribute(name=target, kind=None, parent=parent)
