@@ -9,6 +9,7 @@ from typing import (
 )
 import ast
 import itertools
+import re
 
 import attr
 
@@ -52,6 +53,9 @@ def get_docstring(
 
 
 def taglink(o: model.Documentable, page_url: str, label: Optional["Flattenable"] = None) -> Tag:
+    """
+    Create a link to an object that exists in the system.
+    """
     if not o.isVisible:
         o.system.msg("html", "don't link to %s"%o.fullName())
 
@@ -65,7 +69,9 @@ def taglink(o: model.Documentable, page_url: str, label: Optional["Flattenable"]
         # if the query string is non-empty.
         url = url[len(page_url):]
 
-    ret: Tag = tags.a(label, href=url)
+    ret: Tag = tags.a(label, href=url, class_='internal-link')
+    if label != o.fullName():
+        ret(title=o.fullName())
     return ret
 
 
@@ -74,6 +80,13 @@ class _EpydocLinker(DocstringLinker):
     def __init__(self, obj: model.Documentable):
         self.obj = obj
 
+    @staticmethod
+    def _create_intersphinx_link(label:"Flattenable", url:str) -> Tag:
+        """
+        Create a link with the special 'intersphinx-link' CSS class.
+        """
+        return tags.a(label, href=url, class_='intersphinx-link')
+
     def look_for_name(self,
             name: str,
             candidates: Iterable[model.Documentable],
@@ -114,7 +127,7 @@ class _EpydocLinker(DocstringLinker):
 
         url = self.look_for_intersphinx(fullID)
         if url is not None:
-            return tags.a(label, href=url)
+            return self._create_intersphinx_link(label, url=url)
 
         return tags.transparent(label)
 
@@ -128,7 +141,7 @@ class _EpydocLinker(DocstringLinker):
             if isinstance(resolved, model.Documentable):
                 xref = taglink(resolved, self.obj.page_object.url, label)
             else:
-                xref = tags.a(label, href=resolved)
+                xref = self._create_intersphinx_link(label, url=resolved)
         ret: Tag = tags.code(xref)
         return ret
 
@@ -248,14 +261,16 @@ class FieldDesc:
         formatted = self.body or self._UNDOCUMENTED
         fieldNameTd: List[Tag] = []
         if self.name:
-            name = self.name
-
             # Add the stars to the params names just before generating the field stan, not before.
-            if isinstance(name, VariableArgument):
-                name = f"*{name}"
-            elif isinstance(name, KeywordArgument):
-                name = f"**{name}"
-            
+            if isinstance(self.name, VariableArgument):
+                prefix = "*"
+            elif isinstance(self.name, KeywordArgument):
+                prefix = "**"
+            else:
+                prefix = ""
+
+            name = prefix + insert_break_points(self.name)
+
             stan_name = tags.span(class_="fieldArg")(name)
             if self.type:
                 stan_name(":")
@@ -942,3 +957,30 @@ def format_constant_value(obj: model.Attribute) -> "Flattenable":
     """
     rows = list(_format_constant_value(obj))
     return tags.table(class_='valueTable')(*rows)
+
+def insert_break_points(text: str) -> str:
+    """
+    Browsers aren't smart enough to recognize word breaking opportunities in
+    snake_case or camelCase, so this function helps them out by inserting
+    zero-width spaces.
+    """
+    match = re.match('(__)?(.*?)(__)?$', text)
+    assert match is not None # the regex always matches
+    prefix, text, suffix = match.groups(default='')
+
+    if text.islower() or text.isupper():
+        # We assume snake_case or SCREAMING_SNAKE_CASE.
+        text_with_breaks = text.replace('_', '\u200b_')
+    else:
+        # We assume camelCase.  We're not using a regex because we also want it
+        # to work with non-ASCII characters (and the Python re module does not
+        # support checking for Unicode properties using something like \p{Lu}).
+        text_with_breaks = ''
+        previous_was_upper = False
+        for c in text:
+            if c.isupper() and not previous_was_upper:
+                text_with_breaks += '\u200b'
+            text_with_breaks += c
+            previous_was_upper = c.isupper()
+
+    return prefix + text_with_breaks + suffix
